@@ -60,8 +60,6 @@ def eva():
 
 
 def main():
-    # Setup EVA environment in user home directory
-    bootstrap_environment()
     mode = ConfigurationManager().get_value('core', 'mode')
     init_builtin_udfs(mode=mode)
     eva()
